Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(703)

Unified Diff: runtime/observatory/lib/src/app/application.dart

Issue 897193002: Finish moving service protocol to json rpc. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: code review Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/observatory/lib/service_common.dart ('k') | runtime/observatory/lib/src/app/page.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/observatory/lib/src/app/application.dart
diff --git a/runtime/observatory/lib/src/app/application.dart b/runtime/observatory/lib/src/app/application.dart
index cee60ba074e90c6ecd8b375079c35fda2aebae26..447e8db1e0b4e627a187cd292d85dbd734ebe2c1 100644
--- a/runtime/observatory/lib/src/app/application.dart
+++ b/runtime/observatory/lib/src/app/application.dart
@@ -103,6 +103,9 @@ class ObservatoryApplication extends Observable {
}
void _registerPages() {
+ _pageRegistry.add(new VMPage(this));
+ _pageRegistry.add(new FlagsPage(this));
+ _pageRegistry.add(new InspectPage(this));
_pageRegistry.add(new ClassTreePage(this));
_pageRegistry.add(new DebuggerPage(this));
_pageRegistry.add(new CpuProfilerPage(this));
@@ -111,9 +114,9 @@ class ObservatoryApplication extends Observable {
_pageRegistry.add(new VMConnectPage(this));
_pageRegistry.add(new ErrorViewPage(this));
_pageRegistry.add(new MetricsPage(this));
// Note that ServiceObjectPage must be the last entry in the list as it is
// the catch all.
- _pageRegistry.add(new ServiceObjectPage(this));
+ _pageRegistry.add(new ErrorPage(this));
}
void _onError(ServiceError error) {
@@ -153,11 +156,12 @@ class ObservatoryApplication extends Observable {
if (_traceView != null) {
_traceView.tracer = Tracer.current;
}
+ Uri uri = Uri.parse(url);
for (var i = 0; i < _pageRegistry.length; i++) {
var page = _pageRegistry[i];
- if (page.canVisit(url)) {
+ if (page.canVisit(uri)) {
_installPage(page);
- page.visit(url, argsMap);
+ page.visit(uri, argsMap);
return;
}
}
@@ -111,9 +114,9 @@ class ObservatoryApplication extends Observable {
_pageRegistry.add(new ErrorViewPage(this));
_pageRegistry.add(new MetricsPage(this));
- // Note that ServiceObjectPage must be the last entry in the list as it is
+ // Note that ErrorPage must be the last entry in the list as it is
// the catch all.
« no previous file with comments | « runtime/observatory/lib/service_common.dart ('k') | runtime/observatory/lib/src/app/page.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698